Linux Setup — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Linux Setup

## Overview

- Install Python 3.8

- Install Poetry

- Clone the PyMedPhys git repo

- Run `poetry install -E all` within the root of the repo

- Run `poetry run pre-commit install`

- Install `pandoc` via your package manager

  - eg. `sudo apt-get install pandoc`

You’re good to go.

## Opinionated Recommendations

- Install Python with pyenv

  - Install prerequisites

  - Install pyenv

  - Configure pyenv

- Install VSCode as your code editor

- Install Jupyter Lab to work with Notebooks